pub fn execute_with_stats(
program: &BytecodeProgram,
env: &VmEnv,
) -> Result<(VmValue, VmStats), VmError>Expand description
Execute a BytecodeProgram and return both the result and execution statistics.
pub fn execute_with_stats(
program: &BytecodeProgram,
env: &VmEnv,
) -> Result<(VmValue, VmStats), VmError>Execute a BytecodeProgram and return both the result and execution statistics.