pub struct BytecodeProgram {
pub instructions: Vec<Instruction>,
}Expand description
A compiled, flat sequence of Instructions.
Fields
instructions: Vec<Instruction>The ordered list of instructions.
Implementations
Sourceimpl BytecodeProgram
impl BytecodeProgram
Sourcepub fn push(&mut self, instr: Instruction) -> usize
pub fn push(&mut self, instr: Instruction) -> usize
Append an instruction and return its absolute index.
Sourcepub fn patch_jump(&mut self, idx: usize, target: usize)
pub fn patch_jump(&mut self, idx: usize, target: usize)
Patch the jump target of the instruction at idx.
Panics in debug builds if idx does not contain a jump instruction.