pub fn check_complexity(
complexity: &ExprComplexity,
thresholds: &ComplexityThresholds,
) -> Vec<ComplexityWarning>Expand description
Check complexity metrics against thresholds and return any warnings.
pub fn check_complexity(
complexity: &ExprComplexity,
thresholds: &ComplexityThresholds,
) -> Vec<ComplexityWarning>Check complexity metrics against thresholds and return any warnings.