ConstantPropagator

Struct ConstantPropagator 

pub struct ConstantPropagator { /* private fields */ }
The constant propagation compiler pass.

Performs a bottom-up sweep over a TLExpr tree, evaluating subexpressions at compile time when all operands are TLExpr::Constant(f64) values. Runs to a fixed point (i.e. repeated until no further changes occur) or until config.max_passes is reached.

Implementations

Source

impl ConstantPropagator

pub fn new(config: ConstPropConfig) -> Self

Create a new propagator with the supplied configuration.

pub fn with_default() -> Self

Create a new propagator with default configuration.

pub fn run(&self, expr: TLExpr) -> (TLExpr, ConstPropStats)

Run constant propagation to a fixed point.

Returns (simplified_expr, stats).

pub fn as_constant(expr: &TLExpr) -> Option<f64>

Extract the numeric value if expr is a Constant, otherwise None.

pub fn count_nodes(expr: &TLExpr) -> u64

Count the total number of nodes in an expression tree.