RecoveryAction

Enum RecoveryAction 

pub enum RecoveryAction {
    Continue,
    SkipExpression,
    AbortProgram,
}
Action the tolerant driver takes after reporting a diagnostic.

Variants



Continue

Keep compiling the current expression and then move on.



SkipExpression

Drop the current expression (slot becomes None) and proceed to the next expression.



AbortProgram

Stop compilation immediately; remaining expressions become None.

Implementations

Source

impl RecoveryAction

pub fn is_abort(self) -> bool

Returns true when this action aborts the whole program.

pub fn drops_expression(self) -> bool

Returns true when this action drops the current expression slot.