pub struct JitStats {
pub hot_paths: usize,
pub cold_compilations: usize,
pub jit_hits: usize,
pub jit_upgrades: usize,
}Expand description
Statistics snapshot from a JitCompiler.
Fields
hot_paths: usizeNumber of distinct expressions currently promoted to the hot-path cache.
cold_compilations: usizeTotal number of compile calls that went through the cold path (including the final cold call that triggers an upgrade).
jit_hits: usizeNumber of compile calls that returned a pre-compiled hot-path graph.
jit_upgrades: usizeNumber of expressions that were upgraded from cold to hot (promoted).