Canonicalizer

Struct Canonicalizer 

pub struct Canonicalizer {
    pub sort_commutative: bool,
    pub flatten_nested: bool,
    pub elim_double_neg: bool,
}
Expression canonicalizer with configurable rules.

Fields

sort_commutative: bool

Whether to sort commutative operands (AND, OR).

flatten_nested: bool

Whether to flatten nested same-op expressions.

elim_double_neg: bool

Whether to eliminate double negations.

Implementations

Source

impl Canonicalizer

pub fn new() -> Self

Create a new canonicalizer with all rules enabled.

pub fn with_sort_commutative(self, v: bool) -> Self

Set whether to sort commutative operands.

pub fn with_flatten_nested(self, v: bool) -> Self

Set whether to flatten nested same-op expressions.

pub fn with_elim_double_neg(self, v: bool) -> Self

Set whether to eliminate double negations.

pub fn canonicalize(&self, expr: &TLExpr) -> (TLExpr, CanonicalStats)

Canonicalize an expression, returning the normalized form and stats.

pub fn canonical_key(&self, expr: &TLExpr) -> String

Produce a deterministic canonical key string for cache use.