pub enum RecoveryStrategy {
SkipOnError,
SkipOnFatal,
AbortOnAny,
}Expand description
Configurable error-recovery policy for the tolerant compiler.
Variants
SkipOnError
Skip only the offending expression on any blocking diagnostic (Error or Fatal). Every well-formed expression is still compiled.
This is the most tolerant mode and the default for partial error recovery.
SkipOnFatal
Skip the offending expression on Severity::Error but abort the
entire program on Severity::Fatal.
AbortOnAny
Abort on the first blocking diagnostic (Error or Fatal). Warnings and Infos are still collected but never cause an abort.
This is functionally equivalent to the pre-existing strict compilation mode but also returns the partial diagnostics collected so far.
Implementations
Sourceimpl RecoveryStrategy
impl RecoveryStrategy
Sourcepub fn decide(self, severity: Severity) -> RecoveryAction
pub fn decide(self, severity: Severity) -> RecoveryAction
Decide what the driver should do for a diagnostic of this severity.